<!DOCTYPE html>
<html>
	<head>
		<title>Simple Map</title>
		<meta name="viewport" content="initial-scale=1.0">
		<meta charset="utf-8">
		<link href="includes/styles.css" rel="stylesheet" type="text/css">
	</head>
	<body>	
	<div align="center">
		<p><b>Google Map API Sample</b><br> Please insert address and hit "Show Address". <br> 
		You can try multiple addresses to check directions and path in this sample.</p>
	</div>
	<div id="googlemap"></div>
	<script src="https://maps.googleapis.com/maps/api/js?key=AIzaSyB5YX5hVXYTsIaaq8NXPePu2SodzmonUhU&callback=initMap" async defer></script>
	<script>
      // define vars
		var map, mapLatLng, geocoder, marker, polyline, repeated_Address_flag, stopOver_directions;		// map variabls
		var markers = [];												// array for all markers
		var path = []; 												// array for all path
		var address_bank = [];										// address array for draw path and waypoints
		var waypoints = [];											// array for all waypoints between addresses
		var default_address;											// default address
		var directionsService, directionsDisplay;				// direction & waypoints variabls 
		
		function initMap() {
		// strat up initializations / first run
		default_address = "45 Wangaratta St Richmond VIC 3121"; // start up address
		address_bank.push(default_address);
		stopOver_directions = true;
		waypoints.push({
			location: default_address,
			stopover: stopOver_directions
		});
		
		// prepare map with marker 				
		mapLatLng = {lat: -37.824182	 , lng: 144.992536};			// default position
		var mapOptions = {
									zoom: 		13,
									center: 		mapLatLng,
									mapTypeId: 	google.maps.MapTypeId.ROADMAP
								};

		map = new google.maps.Map(document.getElementById('googlemap'), mapOptions);			// set map
		addMarker( map, mapLatLng, default_address);														// set markers
		
		// path and directions
		directionsService = new google.maps.DirectionsService;
		directionsDisplay = new google.maps.DirectionsRenderer;
		polyline = new google.maps.Polyline({
												strokeColor:		"#0000FF",  // RRGGBB - R=red, G=green, B=blue
												strokeOpacity: 	0.4      	// opacity of line
												}); 
		polyline.setMap(map);													// set polylines
		directionsDisplay.setOptions({
										polylineOptions: {
											strokeColor: 'red'  // set direction path color
										}
		});
		directionsDisplay.setMap(map);
		
		// add event for input address from user
		geocoder = new google.maps.Geocoder();
		document.getElementById('submit').addEventListener('click', function() {
						geocodeAddress(geocoder, map);
					});		

      }

		function geocodeAddress(geocoder, resultsMap) {
			var address = document.getElementById('address').value;
			if (repeat_Address(address) == false) {			// check for repeated input from user
				geocoder.geocode({'address': address}, function(results, status) {
							if (status === 'OK') {
								address_bank.push(address);		// save address
								waypoints.push({						// save waypoint
									location: address,
									stopover: stopOver_directions
								});

								resultsMap.setCenter(results[0].geometry.location);
								addMarker( resultsMap, results[0].geometry.location, address);		// add markers					
							} else {
								alert('GoogleMap API was not successful for the following reason: \n' + status);
							}
						});
			}
		}
		
		function repeat_Address(address){
			if ( address == address_bank[address_bank.length - 1] ){
				repeated_Address_flag = true;
			}else{
				repeated_Address_flag = false;
			}
			return repeated_Address_flag;
		}
		
		// ----------------------------------------------------- markers
		function addMarker(mMap, mPos, mTitle){
			marker = new google.maps.Marker({
														position: 	mPos,
														map: 			mMap,
														title: 		mTitle,
														label: "+"				// markers sign 
													});
			markers.push(marker);
			
			// add path and directions
			drawPath(marker.getPosition());	// draw path
			calculateAndDisplayRoute();		// draw direction (route)			
		}
		
		function deleteMarkers(){
			for (var i = 0; i < markers.length; i++) {
				markers[i].setMap(null);
			}
			deletePath();				// remove previous path on markers
			deleteDirections();		// remove previous directions on markers
		}
		
		// ----------------------------------------------------- Path 
		function drawPath(pPos){
			path.push(pPos);
			if (path.length >= 2) polyline.setPath(path);
		}
		
		function deletePath(){
			polyline.setMap(null);
			path = [];
			polyline = new google.maps.Polyline({
												strokeColor:		"#0000FF",  // RRGGBB - R=red, G=green, B=blue
												strokeOpacity: 	0.4      	// opacity of line
												}); 
			polyline.setMap(map);
		}
		
		// ----------------------------------------------------- directions
		function calculateAndDisplayRoute(){		
			if (address_bank.length >= 2){
				stopOver_directions = false;
				directionsService.route({
										origin: address_bank[address_bank.length - 1],
										destination: address_bank[address_bank.length - 2],
										waypoints: waypoints,
										optimizeWaypoints: true, 
										travelMode: 'DRIVING'
									}, function(response, status) {
																		if (status === 'OK') {
																			directionsDisplay.setDirections(response);
																		} else {
																			window.alert('Directions request failed due to ' + status);
																		}
																	});
			}
			
		}
		
		function deleteDirections(){
			directionsDisplay.setMap(null);
			address_bank = [];
			waypoints = [];
			directionsDisplay.setOptions({
										polylineOptions: {
											strokeColor: 'red'  // set direction path color
										}
			});
			directionsDisplay.setMap(map);
		}

	</script>

	<div id="address-panel">	
		<input id="address" type="textbox" value="45 Wangaratta St Richmond VIC 3121">
		<div id="inner">	
			<input id="submit" type="button" value="Show Address">
			<input onclick="deleteMarkers();" type="button" value="Remove Markers">
		</div>
	</div>
	
	<div class="copyright" align="center">Copyright &copy; 2017 - Emperor Katax - All Rights Reserved</div>
	
	</body>
</html>